class ReceiveConnectionsConstants:
    def __init__(self):
        self.RECEIVECONNECTIONDATATIMEOUT = 4
        self.CONNECTION_DATA_BUFFER = 1024
        self.TESTDATA = 'TEST'